@@ -17,7 +17,7 @@ class Page:
         # 当前页数
         self.current = int(current)
         # 总页数
-        self.pages = ceil(int(self.total) / int(self.page_size))
+        self.pages = ceil(self.total / int(self.page_size))
         # 是否存在前一页
         self.hasPrevious: bool = int(self.current) > 1
         # 是否存在下一页
