@@ -1,7 +1,10 @@
+import logging
+import traceback
 from datetime import datetime
 from decimal import Decimal
 
-from sqlalchemy.orm import Session
+from sqlalchemy.orm import Session, sessionmaker, scoped_session
+from sqlalchemy.util.compat import contextmanager
 from tornado.options import options
 
 
@@ -16,9 +19,19 @@ class SqlAlchemyHelper:
         else:
             self.pool = pool
 
-    def make_session(self, autocommit=True, **kwargs):
-        session = Session(self.pool, autocommit=autocommit, **kwargs)
-        return session
+    @contextmanager
+    def make_session(self, **kwargs):
+        db_session = scoped_session(sessionmaker(bind=self.pool, **kwargs))
+        session = db_session()
+        try:
+            yield session
+            session.commit()
+        except Exception as e:
+            logging.error(e.args)
+            logging.error(traceback.format_exc())
+            session.rollback()
+        finally:
+            session.close()
 
 
 def alchemy_default_to_dict(params, data, repetition=False):
