@@ -8,6 +8,7 @@ import inspect
 import json
 import logging
 import time
+import traceback
 import types
 from datetime import datetime
 from decimal import Decimal
@@ -18,6 +19,8 @@ from tornado import httputil
 from tornado.escape import utf8
 from tornado.ioloop import IOLoop
 from tornado.web import RequestHandler, Application
+
+from lesscode.utils.es_log.record_log import es_record_log
 from lesscode.web.status_code import StatusCode
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.response_result import ResponseResult
@@ -235,6 +238,7 @@ class BaseHandler(RequestHandler):
         :param kwargs:
         :return:
         """
+        es_record_log(request=self.request, message=traceback.format_exc(), level="error", status_code=status_code)
         error = kwargs["exc_info"]
         if isinstance(error[1], BusinessException):
             self.set_status(200)
